package com.goer.project.model.modelDbs.mapper;

import java.util.List;
import com.goer.project.model.modelDbs.domain.ModelDbs;
import org.springframework.stereotype.Repository;

/**
 * 模型对象数据库配置Mapper接口
 * 
 * @author goer
 * @date 2022-01-17
 */
@Repository
public interface ModelDbsMapper 
{
    /**
     * 查询模型对象数据库配置
     * 
     * @param id 模型对象数据库配置主键
     * @return 模型对象数据库配置
     */
    public ModelDbs selectModelDbsById(Long id);

    /**
     * 查询模型对象默认数据库配置
     *
     * @param projectId 模型对象主键
     * @return 模型对象数据库配置
     */
    public ModelDbs selectDefaultDbByProjectId(Long projectId);

    /**
     * 查询模型对象数据库配置列表
     * 
     * @param modelDbs 模型对象数据库配置
     * @return 模型对象数据库配置集合
     */
    public List<ModelDbs> selectModelDbsList(ModelDbs modelDbs);

    /**
     * 新增模型对象数据库配置
     * 
     * @param modelDbs 模型对象数据库配置
     * @return 结果
     */
    public int insertModelDbs(ModelDbs modelDbs);

    /**
     * 修改模型对象数据库配置
     * 
     * @param modelDbs 模型对象数据库配置
     * @return 结果
     */
    public int updateModelDbs(ModelDbs modelDbs);

    /**
     * 删除模型对象数据库配置
     * 
     * @param id 模型对象数据库配置主键
     * @return 结果
     */
    public int deleteModelDbsById(Long id);

    /**
     * 删除
     *
     * @param projectId 模型对象id
     * @return 结果
     */
    public int deleteModelDbsByProjectId(Long projectId);

    /**
     * 批量删除模型对象数据库配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteModelDbsByIds(String[] ids);

    /**
     * 修改模型对象数据库配置
     *
     * @param modelDbs 模型对象数据库配置
     * @return 结果
     */
    public int resetDefaultDb(ModelDbs modelDbs);
}
